@@ -1,10 +1,10 @@
 """
 
-LDAP Groups v1 - A django Active Directory group management abstraction
+LDAP Groups v2 - A python/django Active Directory group management abstraction
     that uses python-ldap as a backend for cross-platform compatability.
 
 Dependencies:
-    python-ldap==2.4.13
+    python-ldap>=2.4.13
 
 ldap-groups is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser Public License as published by
@@ -29,5 +29,5 @@ from groups import ADGroup
 # Version Classification
 # Major Updates, Minor Updates, Revision/Bugfix Updates
 #
-VERSION = ("2", "5", "0")
+VERSION = ("2", "5", "1")
 __version__ = ".".join(VERSION)
